==> drumstick-2.7.0-1-armv7h.pkg.tar.xz: usr/lib/cmake/drumstick/drumstick-rt-targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Drumstick::RT" for configuration "None"
set_property(TARGET Drumstick::RT APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::RT PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "Qt5::Core"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libdrumstick-rt.so.2.7.0"
  IMPORTED_SONAME_NONE "libdrumstick-rt.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS Drumstick::RT )
list(APPEND _IMPORT_CHECK_FILES_FOR_Drumstick::RT "${_IMPORT_PREFIX}/lib/libdrumstick-rt.so.2.7.0" )

# Import target "Drumstick::drumstick-rt-alsa-in" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-alsa-in APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-alsa-in PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-alsa-in.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS Drumstick::drumstick-rt-alsa-in )
list(APPEND _IMPORT_CHECK_FILES_FOR_Drumstick::drumstick-rt-alsa-in "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-alsa-in.so" )

# Import target "Drumstick::drumstick-rt-alsa-out" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-alsa-out APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-alsa-out PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-alsa-out.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS Drumstick::drumstick-rt-alsa-out )
list(APPEND _IMPORT_CHECK_FILES_FOR_Drumstick::drumstick-rt-alsa-out "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-alsa-out.so" )

# Import target "Drumstick::drumstick-rt-eassynth" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-eassynth APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-eassynth PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-eassynth.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS Drumstick::drumstick-rt-eassynth )
list(APPEND _IMPORT_CHECK_FILES_FOR_Drumstick::drumstick-rt-eassynth "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-eassynth.so" )

# Import target "Drumstick::drumstick-rt-net-in" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-net-in APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-net-in PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-net-in.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS Drumstick::drumstick-rt-net-in )
list(APPEND _IMPORT_CHECK_FILES_FOR_Drumstick::drumstick-rt-net-in "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-net-in.so" )

# Import target "Drumstick::drumstick-rt-net-out" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-net-out APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-net-out PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-net-out.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS Drumstick::drumstick-rt-net-out )
list(APPEND _IMPORT_CHECK_FILES_FOR_Drumstick::drumstick-rt-net-out "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-net-out.so" )

# Import target "Drumstick::drumstick-rt-oss-in" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-oss-in APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-oss-in PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-oss-in.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS Drumstick::drumstick-rt-oss-in )
list(APPEND _IMPORT_CHECK_FILES_FOR_Drumstick::drumstick-rt-oss-in "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-oss-in.so" )

# Import target "Drumstick::drumstick-rt-oss-out" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-oss-out APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-oss-out PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-oss-out.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS Drumstick::drumstick-rt-oss-out )
list(APPEND _IMPORT_CHECK_FILES_FOR_Drumstick::drumstick-rt-oss-out "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-oss-out.so" )

# Import target "Drumstick::drumstick-rt-fluidsynth" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-fluidsynth APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-fluidsynth PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-fluidsynth.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS Drumstick::drumstick-rt-fluidsynth )
list(APPEND _IMPORT_CHECK_FILES_FOR_Drumstick::drumstick-rt-fluidsynth "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-fluidsynth.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> drumstick-2.7.1-2-armv7h.pkg.tar.xz: usr/lib/cmake/drumstick/drumstick-rt-targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Drumstick::RT" for configuration "None"
set_property(TARGET Drumstick::RT APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::RT PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "Qt6::Core"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libdrumstick-rt.so.2.7.1"
  IMPORTED_SONAME_NONE "libdrumstick-rt.so.2"
  )

list(APPEND _cmake_import_check_targets Drumstick::RT )
list(APPEND _cmake_import_check_files_for_Drumstick::RT "${_IMPORT_PREFIX}/lib/libdrumstick-rt.so.2.7.1" )

# Import target "Drumstick::drumstick-rt-alsa-in" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-alsa-in APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-alsa-in PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-alsa-in.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets Drumstick::drumstick-rt-alsa-in )
list(APPEND _cmake_import_check_files_for_Drumstick::drumstick-rt-alsa-in "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-alsa-in.so" )

# Import target "Drumstick::drumstick-rt-alsa-out" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-alsa-out APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-alsa-out PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-alsa-out.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets Drumstick::drumstick-rt-alsa-out )
list(APPEND _cmake_import_check_files_for_Drumstick::drumstick-rt-alsa-out "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-alsa-out.so" )

# Import target "Drumstick::drumstick-rt-eassynth" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-eassynth APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-eassynth PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-eassynth.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets Drumstick::drumstick-rt-eassynth )
list(APPEND _cmake_import_check_files_for_Drumstick::drumstick-rt-eassynth "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-eassynth.so" )

# Import target "Drumstick::drumstick-rt-net-in" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-net-in APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-net-in PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-net-in.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets Drumstick::drumstick-rt-net-in )
list(APPEND _cmake_import_check_files_for_Drumstick::drumstick-rt-net-in "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-net-in.so" )

# Import target "Drumstick::drumstick-rt-net-out" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-net-out APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-net-out PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-net-out.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets Drumstick::drumstick-rt-net-out )
list(APPEND _cmake_import_check_files_for_Drumstick::drumstick-rt-net-out "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-net-out.so" )

# Import target "Drumstick::drumstick-rt-oss-in" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-oss-in APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-oss-in PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-oss-in.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets Drumstick::drumstick-rt-oss-in )
list(APPEND _cmake_import_check_files_for_Drumstick::drumstick-rt-oss-in "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-oss-in.so" )

# Import target "Drumstick::drumstick-rt-oss-out" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-oss-out APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-oss-out PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-oss-out.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets Drumstick::drumstick-rt-oss-out )
list(APPEND _cmake_import_check_files_for_Drumstick::drumstick-rt-oss-out "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-oss-out.so" )

# Import target "Drumstick::drumstick-rt-fluidsynth" for configuration "None"
set_property(TARGET Drumstick::drumstick-rt-fluidsynth APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(Drumstick::drumstick-rt-fluidsynth PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-fluidsynth.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets Drumstick::drumstick-rt-fluidsynth )
list(APPEND _cmake_import_check_files_for_Drumstick::drumstick-rt-fluidsynth "${_IMPORT_PREFIX}/lib/drumstick2/libdrumstick-rt-fluidsynth.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
